/*
 *  Qactus - A Qt-based OBS client
 *
 *  Copyright (C) 2018 Javier Llorente <javier@opensuse.org>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) version 3.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "syntaxhighlighter.h"

SyntaxHighlighter::SyntaxHighlighter(QTextDocument *parent)
    : QSyntaxHighlighter(parent)
{
    HighlightingRule rule;

    QColor green(34, 153, 34);
    addedLineFormat.setForeground(green);
    rule.pattern = QRegularExpression("^(\\+.*)$|^(.*added)$|^(add.*)$");
    rule.format = addedLineFormat;
    highlightingRules.append(rule);

    QColor red(221, 68, 68);
    removedLineFormat.setForeground(red);
    rule.pattern = QRegularExpression("^(-.*)$|^(.*deleted)$|^(delete.*)$");
    rule.format = removedLineFormat;
    highlightingRules.append(rule);

    QColor gray(88, 90, 90);
    atLineFormat.setForeground(gray);
    rule.pattern = QRegularExpression("^(@.*)$");
    rule.format = atLineFormat;
    highlightingRules.append(rule);
}

void SyntaxHighlighter::highlightBlock(const QString &text)
{
    foreach (const HighlightingRule &rule, highlightingRules) {
        QRegularExpressionMatchIterator matchIterator = rule.pattern.globalMatch(text);
        while (matchIterator.hasNext()) {
            QRegularExpressionMatch match = matchIterator.next();
            setFormat(match.capturedStart(), match.capturedLength(), rule.format);
        }
    }
}
